@@ -1,11 +1,9 @@
 package Text::ANSITable;
 
 use 5.010001;
-use experimental 'smartmatch';
-use strict;
-use warnings;
 use Log::Any '$log';
 use Moo;
+use experimental 'smartmatch';
 
 #use List::Util 'first';
 use Color::ANSI::Util qw(ansi16fg ansi16bg
@@ -17,7 +15,7 @@ use Scalar::Util 'looks_like_number';
 use Text::ANSI::Util qw(ta_mbswidth_height ta_mbpad ta_add_color_resets
                         ta_mbwrap);
 
-our $VERSION = '0.14'; # VERSION
+our $VERSION = '0.15'; # VERSION
 
 my $ATTRS = [qw(
 
@@ -1569,7 +1567,7 @@ Text::ANSITable - Create a nice formatted table using extended ASCII and ANSI co
 
 =head1 VERSION
 
-version 0.14
+version 0.15
 
 =head1 SYNOPSIS
 
